@@ -377,6 +377,7 @@ void syntax()
    printf("   -s --stdout --no-syslog\n");
    printf("   -n --no-fork\n");
    printf("   -v --verbose\n");
+   printf("   -V --version\n");
    printf("   -d --disconnect-hack\n");
    printf("   -q --link-quality\n");
    printf("   -a --authenticate\n");
@@ -420,6 +421,7 @@ void readargs(int argc, char** argv, arg_t* args)
       {"help", 0, 0, 'h'},
       {"no-fork", 0, 0, 'n'},
       {"verbose", 0, 0, 'v'},
+      {"version", 0, 0, 'V'},
       {"authenticate", 0, 0, 'a'},
       {"no-syslog", 0, 0, 's'},
       {"uid", 1, 0, 'u'},
@@ -428,7 +430,7 @@ void readargs(int argc, char** argv, arg_t* args)
       {"link-quality", 1, 0, 'q'}
    };
    int idx = 0;
-   while (-1 != (c = getopt_long(argc, argv, "-c:b:t:i:o:sqhndvag:u:",long_opts, &idx))) {
+   while (-1 != (c = getopt_long(argc, argv, "-c:b:t:i:o:sqhVndvag:u:",long_opts, &idx))) {
       switch (c) {
          case 'c':
             args->config = optarg;
@@ -466,6 +468,9 @@ void readargs(int argc, char** argv, arg_t* args)
          case 'q':
             args->linkquality = true;
             break;
+         case 'V':
+            printf("Bluemon version %s.\n", VERSION);
+            break;
          case 'h':
          case ':':
          case '?':
@@ -546,7 +551,7 @@ void sighandle(int signum)
          }
          message(false, "Caught SIGTERM, announcing our demise\n");
          if (NULL != conn) 
-            dbus_connection_close(conn);
+            dbus_connection_unref(conn);
          exit(0);
       case SIGHUP:
          readoptions(args, &opts);
@@ -866,6 +871,6 @@ int main(int argc, char ** argv)
    }
    // disconnect socket
    if (NULL != conn)
-      dbus_connection_close(conn);
+      dbus_connection_unref(conn);
 }
 
